==> homematic-manager-1.0.4.tgz: package/Readme.en.md <==
# HomeMatic Manager

## Documentation

The HomeMatic Manager is a web interface for [HomeMatic](http://www.homematic.com)-interface processes
(rfd, hs485d, [Homegear](http://www.homegear.eu)).

With HomeMatic Manager it's possible to pair and delete devices, do device configurations and manage links. Furthermore
you can assign RF devices to specific interfaces, enable/disable roaming and many more.

### Installation

* homematic-manager needs a [Node.js](http://nodejs.org/download/) installation
* install: ```npm install -g homematic-manager```

### Configuration

* edit `~/.hm-manager/hm-manager.json` (respectively `/usr/local/lib/node_modules/homematic-manager/settings-default.json` before first start):

### start HomeMatic-Manager 

* ```hm-manager start```
* open [http://127.0.0.1:8081](http://127.0.0.1:8081)


## Changelog

see [German language Readme](Readme.en)


## License

Copyright (c) 2014, 2015 Anli, Hobbyquaker

[CC BY-NC-SA 4.0](http://creativecommons.org/licenses/by-nc-sa/4.0/)


Der obige Urheberrechtsvermerk ist in allen Kopien oder Teilkopien der Software beizulegen.

DIE SOFTWARE WIRD OHNE JEDE AUSDRÜCKLICHE ODER IMPLIZIERTE GARANTIE BEREITGESTELLT, EINSCHLIESSLICH DER GARANTIE ZUR BENUTZUNG FÜR DEN VORGESEHENEN ODER EINEM BESTIMMTEN ZWECK SOWIE JEGLICHER RECHTSVERLETZUNG, JEDOCH NICHT DARAUF BESCHRÄNKT. IN KEINEM FALL SIND DIE AUTOREN ODER COPYRIGHTINHABER FÜR JEGLICHEN SCHADEN ODER SONSTIGE ANSPRÜCHE HAFTBAR ZU MACHEN, OB INFOLGE DER ERFÜLLUNG EINES VERTRAGES, EINES DELIKTES ODER ANDERS IM ZUSAMMENHANG MIT DER SOFTWARE ODER SONSTIGER VERWENDUNG DER SOFTWARE ENTSTANDEN.

HomeMatic und BidCoS sind eingetragene Warenzeichen der [eQ-3 AG](http://eq-3.de)

==> homematic-manager-1.0.9.tgz: package/Readme.en.md <==
# Homematic Manager

[Deutschsprachiges Readme](Readme.md)

## Documentation

The Homematic Manager is a web interface for [HomeMatic](http://www.homematic.com)-interface processes
(rfd, hs485d, [Homegear](http://www.homegear.eu)).

With Homematic Manager it's possible to pair and delete devices, do device configurations and manage links. Furthermore
you can assign RF devices to specific interfaces, enable/disable roaming and many more.

### Installation

* Homematic Manager needs a [Node.js](http://nodejs.org/download/) installation
* install: ```sudo npm install -g homematic-manager```

### Configuration

* edit `~/.hm-manager/hm-manager.json` (respectively `/usr/local/lib/node_modules/homematic-manager/settings-default.json` before first start):

### start Homematic Manager

* ```hm-manager start```


## Changelog

see [German language Readme](Readme.md)


## License

Copyright (c) 2014, 2015 Anli, Hobbyquaker

[CC BY-NC-SA 4.0](http://creativecommons.org/licenses/by-nc-sa/4.0/)


Der obige Urheberrechtsvermerk ist in allen Kopien oder Teilkopien der Software beizulegen.

DIE SOFTWARE WIRD OHNE JEDE AUSDRÜCKLICHE ODER IMPLIZIERTE GARANTIE BEREITGESTELLT, EINSCHLIESSLICH DER GARANTIE ZUR BENUTZUNG FÜR DEN VORGESEHENEN ODER EINEM BESTIMMTEN ZWECK SOWIE JEGLICHER RECHTSVERLETZUNG, JEDOCH NICHT DARAUF BESCHRÄNKT. IN KEINEM FALL SIND DIE AUTOREN ODER COPYRIGHTINHABER FÜR JEGLICHEN SCHADEN ODER SONSTIGE ANSPRÜCHE HAFTBAR ZU MACHEN, OB INFOLGE DER ERFÜLLUNG EINES VERTRAGES, EINES DELIKTES ODER ANDERS IM ZUSAMMENHANG MIT DER SOFTWARE ODER SONSTIGER VERWENDUNG DER SOFTWARE ENTSTANDEN.

HomeMatic und BidCoS sind eingetragene Warenzeichen der [eQ-3 AG](http://eq-3.de)
